#[non_exhaustive]pub enum PlanTarget {
Hook {
integration_id: &'static str,
scope: Scope,
tag: String,
},
Mcp {
integration_id: &'static str,
scope: Scope,
name: String,
owner: String,
},
Skill {
integration_id: &'static str,
scope: Scope,
name: String,
owner: String,
},
Instruction {
integration_id: &'static str,
scope: Scope,
name: String,
owner: String,
},
}Expand description
The operation target described by an install/uninstall plan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Hook
Hook target for one integration, scope, and consumer tag.
Fields
Mcp
MCP target for one integration, scope, server name, and owner tag.
Fields
Skill
Skill target for one integration, scope, skill name, and owner tag.
Fields
Instruction
Instruction target for one integration, scope, instruction name, and owner.