Module scope

Module scope 

Where a hook should be installed: globally for the user, or scoped to a single project directory.

Enums

Scope
Install location for a hook.
ScopeKind
Discriminant of Scope without payload, used in the Integration::supported_scopes trait method.