#[non_exhaustive]pub enum SecretPolicy {
RefuseInlineSecretsInLocalScope,
AllowInlineSecretsInLocalScope,
}Expand description
Policy for env values that look secret-bearing in project-local MCP config.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RefuseInlineSecretsInLocalScope
Refuse local-scope installs that would write likely secret env values.
AllowInlineSecretsInLocalScope
Allow likely secret env values even when the config path is local.
Use this only when the caller has made an explicit trust decision about the target project config.