#[non_exhaustive]pub struct HookRuntimeOptions {
pub timeout_seconds: Option<u64>,
pub status_message: Option<String>,
pub async_run: Option<bool>,
pub shell: Option<String>,
pub windows_command: Option<HookCommand>,
pub codex_inline_toml: Option<bool>,
}Expand description
Optional execution configuration for command hooks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timeout_seconds: Option<u64>Maximum time in seconds the harness should allow the hook script to run.
status_message: Option<String>Optional status message the harness should display while executing the hook.
async_run: Option<bool>Whether the hook should run asynchronously (non-blocking).
shell: Option<String>Custom shell path to use when executing the command (e.g. "/bin/bash").
windows_command: Option<HookCommand>Windows-specific command override.
codex_inline_toml: Option<bool>Codex-specific: install inline inside config.toml instead of hooks.json.